



source('r/library.r')
source('r/functions.r')
source('r/data.r')
source('r/graph.r')




dataMaster <- data.frame( age=c(15:70) )




##########
##########
########## Load Data
##########
##########

#--------[ Data - Salary ]--------#
data100 <- read.csv('data/SmartAsset-Salary.csv')
data100$sa_salary <- normalize(data100$sa_salary)
dataMaster <- combineMaster(dataMaster, data100)




#--------[ Data - Female Fertility ]--------#
data200 <- read.csv('data/BlitzResults-Fertility-female.csv')
data200$blitz_infertility <- 1 - normalize(data200$blitz_infertility)
data200$blitz_preg_per_year <- normalize(data200$blitz_preg_per_year)
dataMaster <- combineMaster(dataMaster, data200)




#--------[ Data - Advanced Maternal Age ]--------#
data300 <- read.csv('data/DSHealth-Risk-Female.csv')
data300$dsh_fetus <- 1 - normalize(data300$dsh_fetus)
data300$dsh_birth <- 1 - normalize(data300$dsh_birth)
dataMaster <- combineMaster(dataMaster, data300)

data310 <- read.csv('data/OGMag-AMA-Complications.csv')
data310$ama_ectopic <- 1 -normalize(data310$ama_ectopic)
data310$ama_miscarriage <- 1- normalize(data310$ama_miscarriage)
dataMaster <- combineMaster(dataMaster, data310)




#--------[ Data - Male Fertility ]--------#
data400 <- read.csv('data/NCBI-SpermQuality.csv')
data400$sperm_volume <- normalize(data400$sperm_volume)
data400$sperm_concentration <- normalize(data400$sperm_concentration)
data400$sperm_motility <- normalize(data400$sperm_motility)
data400$sperm_count <- normalize(data400$sperm_count)
data400$sperm_motility_tot <- normalize(data400$sperm_motility_tot)
dataMaster <- combineMaster(dataMaster, data400)




#--------[ Data - Advanced Paternal Age ]--------#
data500 <- read.csv('data/APA-Bipolar.csv')
data500$apa_bpd <- 1 - normalize(data500$apa_bpd)
dataMaster <- combineMaster(dataMaster, data500)

data501 <- read.csv('data/APA-Autism.csv')
data501$apa_autism <- 1 - normalize(data501$apa_autism)
dataMaster <- combineMaster(dataMaster, data501)

data502 <- read.csv('data/APA-Schizophrenia.csv')
data502$apa_schizophrenia <- 1 - normalize(data502$apa_schizophrenia)
dataMaster <- combineMaster(dataMaster, data502)

data503 <- read.csv('data/APA-Intelligence.csv')
data503$apa_iq <- normalize(data503$apa_iq)
dataMaster <- combineMaster(dataMaster, data503)



#--------[ Data - OKCupid Looks By Age ]--------#
data700 <- read.csv('data/OKCupid-Aging-Both.csv')

data700['okc_male_dist'] = abs(data700$age-data700$okc_female)
data700['okc_female_dist'] = abs(data700$age-data700$okc_male)

data700$okc_male <- normalize(data700$okc_male)
data700$okc_female <- normalize(data700$okc_female)
data700$okc_female_dist <- 1 - normalize(data700$okc_female_dist)
data700$okc_male_dist <- 1 - normalize(data700$okc_male_dist)
dataMaster <- combineMaster(dataMaster, data700)




##########
##########
########## Build Model
##########
##########

dataMaster <- cleanMaster(dataMaster)

#--------[ Intermediate - Advanced Maternal Age (Average) ]--------#
dataMaster$ama_average <- (
    dataMaster$dsh_fetus +
    dataMaster$ama_ectopic +
    dataMaster$ama_miscarriage
)/3
dataMaster$ama_average <- normalize(dataMaster$ama_average)

#--------[ Intermediate - Advanced Maternal Age (Average) ]--------#
dataMaster$apa_average <- (
    dataMaster$apa_bpd +
    dataMaster$apa_autism +
    dataMaster$apa_schizophrenia +
    dataMaster$apa_iq
)/4
dataMaster$apa_average <- normalize(dataMaster$apa_average)

#--------[ Final - Male Sexual Market Value ]--------#
dataMaster$smv_male <-(
    dataMaster$sa_salary +
    dataMaster$sperm_motility_tot + 
    dataMaster$apa_average +
    dataMaster$okc_male_dist
)/4
dataMaster$smv_male <- normalize(dataMaster$smv_male)

#--------[ Final - Male Sexual Market Value ]--------#
dataMaster$smv_female <-(
    dataMaster$blitz_preg_per_year +
    dataMaster$blitz_infertility + 
    dataMaster$ama_average +
    dataMaster$okc_female_dist
)/4
dataMaster$smv_female <- normalize(dataMaster$smv_female)

#--------[ Final - Gender Advantage ]--------#
dataMaster$advantage <- dataMaster$smv_male - dataMaster$smv_female





##########
##########
########## Draw Graph
##########
##########

#--------[ Graph - MetaData ]--------#
metaData <- c(
  source='Combined data from various sources',
  file='NA',
  set='000-SMV-Model',
  id='000-SMV-Model',
  title='Sexual Marketplace Value: Final Model',
  xtitle='Age (years)',
  ytitle='Sexual Marketplace Value',
  ltitle='Data',
  aspect=c(16,9),
  lpos='mr'
)

#--------[ Graph - Draw Graph ]--------#
tmpGraph <- createGraph(dataMaster, metaData)
tmpGraph <- drawGraphAlpha(tmpGraph, dataMaster, 'sa_salary', 'Average Salary')
tmpGraph <- drawGraphAlpha(tmpGraph, dataMaster, 'blitz_preg_per_year', 'Female Fertility - Chances of Getting Pregnant Within One Year')
tmpGraph <- drawGraphAlpha(tmpGraph, dataMaster, 'blitz_infertility', 'Female Fertility - Likelyhood to be Infertile')
tmpGraph <- drawGraphAlpha(tmpGraph, dataMaster, 'ama_average', 'Advanced Maternal Age Complications (Average)')
tmpGraph <- drawGraphAlpha(tmpGraph, dataMaster, 'sperm_motility_tot', 'Male Fertility - Total Sperm Motility')
tmpGraph <- drawGraphAlpha(tmpGraph, dataMaster, 'apa_average', 'Advanced Paternal Age Complications (Average)')
tmpGraph <- drawGraphAlpha(tmpGraph, dataMaster, 'okc_male_dist', 'OKCupid - Male looks by age (Distance)')
tmpGraph <- drawGraphAlpha(tmpGraph, dataMaster, 'okc_female_dist', 'OKCupid - Female looks by age (Distance)')

tmpGraph <- drawGraphMaster(tmpGraph, dataMaster, 'smv_male', 'Male Sexual Market Value')
tmpGraph <- drawGraphMaster(tmpGraph, dataMaster, 'smv_female', 'Female Sexual Market Value')

tmpGraph <- tmpGraph + geom_vline(aes(xintercept=34), linetype=2, alpha=0.5)

saveGraph(tmpGraph, metaData)



